==> hooks-1.1.18.tgz: package/es/hooks/use-resize.js <==
function _toConsumableArray(arr) { return _arrayWithoutHoles(arr) || _iterableToArray(arr) || _unsupportedIterableToArray(arr) || _nonIterableSpread(); }
function _nonIterableSpread() { throw new TypeError("Invalid attempt to spread non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }
function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(o); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }
function _iterableToArray(iter) { if (typeof Symbol !== "undefined" && iter[Symbol.iterator] != null || iter["@@iterator"] != null) return Array.from(iter); }
function _arrayWithoutHoles(arr) { if (Array.isArray(arr)) return _arrayLikeToArray(arr); }
function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) arr2[i] = arr[i]; return arr2; }
import { useEffect, useMemo, useRef } from 'react';
import { useStableCallback } from './use-stable-callback';
import { debounce } from 'lodash';
export function useResize(_ref, deps) {
  var el = _ref.el,
    _ref$onResize = _ref.onResize,
    onResize = _ref$onResize === void 0 ? function () {} : _ref$onResize;
  var prevRect = useRef();
  var onResizeFn = useStableCallback(onResize);
  var obs = useMemo(function () {
    var fn = function fn(entries) {
      entries.forEach(function (entry) {
        var _prevRect$current, _prevRect$current2;
        if (((_prevRect$current = prevRect.current) === null || _prevRect$current === void 0 ? void 0 : _prevRect$current.width) !== entry.contentRect.width || ((_prevRect$current2 = prevRect.current) === null || _prevRect$current2 === void 0 ? void 0 : _prevRect$current2.height) !== entry.contentRect.height) {
          onResizeFn === null || onResizeFn === void 0 ? void 0 : onResizeFn(entry);
        }
        prevRect.current = entry.contentRect;
      });
    };
    return new ResizeObserver(debounce(fn, 5));
  }, []);
  useEffect(function () {
    if (el) {
      // 开始监听
      obs === null || obs === void 0 ? void 0 : obs.observe(el);
      return function () {
        obs === null || obs === void 0 ? void 0 : obs.unobserve(el);
        obs === null || obs === void 0 ? void 0 : obs.disconnect();
      };
    }
    return undefined;
  }, [obs, el].concat(_toConsumableArray(deps || [])));
}

==> hooks-1.1.24.tgz: package/es/hooks/use-resize.js <==
function _toConsumableArray(arr) { return _arrayWithoutHoles(arr) || _iterableToArray(arr) || _unsupportedIterableToArray(arr) || _nonIterableSpread(); }
function _nonIterableSpread() { throw new TypeError("Invalid attempt to spread non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }
function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(o); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }
function _iterableToArray(iter) { if (typeof Symbol !== "undefined" && iter[Symbol.iterator] != null || iter["@@iterator"] != null) return Array.from(iter); }
function _arrayWithoutHoles(arr) { if (Array.isArray(arr)) return _arrayLikeToArray(arr); }
function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) arr2[i] = arr[i]; return arr2; }
import { useEffect, useMemo, useRef } from 'react';
import { useStableCallback } from './use-stable-callback';
import { debounce } from 'lodash';
export function useResize(_ref) {
  var el = _ref.el,
    ref = _ref.ref,
    _ref$onResize = _ref.onResize,
    onResize = _ref$onResize === void 0 ? function () {} : _ref$onResize;
  var deps = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : [];
  var prevRect = useRef();
  var onResizeFn = useStableCallback(onResize);
  var obs = useMemo(function () {
    var fn = function fn(entries) {
      entries.forEach(function (entry) {
        var _prevRect$current, _prevRect$current2;
        if (((_prevRect$current = prevRect.current) === null || _prevRect$current === void 0 ? void 0 : _prevRect$current.width) !== entry.contentRect.width || ((_prevRect$current2 = prevRect.current) === null || _prevRect$current2 === void 0 ? void 0 : _prevRect$current2.height) !== entry.contentRect.height) {
          onResizeFn === null || onResizeFn === void 0 ? void 0 : onResizeFn(entry);
        }
        prevRect.current = entry.contentRect;
      });
    };
    return new ResizeObserver(debounce(fn, 5));
  }, [onResizeFn]);
  useEffect(function () {
    var ele = ref ? ref.current : el;
    if (ele) {
      // 开始监听
      obs === null || obs === void 0 ? void 0 : obs.observe(ele);
      return function () {
        obs === null || obs === void 0 ? void 0 : obs.unobserve(ele);
        obs === null || obs === void 0 ? void 0 : obs.disconnect();
      };
    }
    return undefined;
    // eslint-disable-next-line react-hooks/exhaustive-deps
  }, [obs, el, ref].concat(_toConsumableArray(deps)));
}
